# React pagination

React pagination is a simple and customizable notification component for React applications.

![Frontend_System_Design_Questions__Component___HLD_LLD](https://github.com/piyush-eon/react-pagination/assets/51760520/be023ecf-39fb-4cb0-beeb-98519050ba99)

## Installation

You can install React pagination via npm:

```jsx
npm install react-custom-pagination
```

## Usage

To use React pagination in your React application, follow these steps:

Import the useFetchData hook and necessary styles in your component:

```jsx
import useFetchData from "react-pagination";
```

Initialize the useFetchData hook with your preferred position:

```jsx
const { items,
        pagnatedData,
        onClickNext,
        onClickPrev } =
  useFetchData("top-left");
```

Trigger  using the triggerNotification function:

```jsx
triggerNotification({
  type: "success",
  message: "This is a success message!",
  duration: 3000,
});
```

#### Animations

You can specify an animation type for the . The available animations are:

- "fade"
- "pop"
- "slide"

```jsx
triggerNotification({
  type: "success",
  message: "This is a success message with a pop animation!",
  duration: 3000,
  animation: "pop",
});
```

## API

```jsx
useFetchData(position: PositionType)
```

This hook returns an object with the following properties:

- `NotificationComponent`: React element representing the notification container.
- `triggerNotification(notificationProps: NotificationProps)`: Function to trigger a notification with the specified properties.

`NotificationProps`
The triggerNotification function accepts an object of type NotificationProps, which includes:

- type: Type of the notification (success, info, warning, error).
- message: Message to display in the notification.
- duration: Duration in milliseconds for which the notification should be displayed.
- animation (optional): Animation type for the notification (fade, pop, slide).

## Example

Here's a basic example of how to use React pagination:

```jsx
import React from "react";
import useFetchData from "react-pagination";

function App() {
  const { NotificationComponent, triggerNotification } =
    useFetchData("top-left");

  const handleButtonClick = () => {
    triggerNotification({
      type: "success",
      message: "This is a success message!",
      duration: 3000,
    });
  };

  return (
    <div className="App">
      {NotificationComponent}
      <h1 Component</h1>
      <button onClick={handleButtonClick}>Show Success</button>
    </div>
  );
}

export default App;
```

## License

This project is licensed under the MIT License - see the LICENSE file for details.
